@@ -258,9 +258,12 @@ class interface(abstract_instrument_interface.abstract_interface):
             #self.logger.info(f"Need to adjust sensitivity.")
             target_sensitivity = current_mag / max_bound
             #Look for smallest sensitivity larger than target_sensitivity
-            index_new_sensitivity = self.sensitivities.index (
-                                                                min ([i for i in  self.sensitivities if i > target_sensitivity] )
-                                                                )
+            list_possible_sensitivies = [i for i in  self.sensitivities if i > target_sensitivity]
+            if list_possible_sensitivies:
+                new_sensitivity = min(list_possible_sensitivies)
+            else:
+                new_sensitivity = max(self.sensitivities)
+            index_new_sensitivity = self.sensitivities.index (new_sensitivity)
             return self.set_sensitivity(index_new_sensitivity,log = False)
 
     def set_refresh_time(self, refresh_time):
